@@ -4,7 +4,7 @@ workorder.
 
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.server import hook
 
 from cubes.workorder.hooks import UpdateProgressOp
@@ -16,7 +16,7 @@ class UpdateProgressOnActivityModification(hook.Hook):
     events = ('after_update_entity', )
 
     def __call__(self):
-        if 'duration' in self.entity.edited:
+        if 'duration' in self.entity.cw_edited:
             for workorder in self.entity.done_for:
                 UpdateProgressOp.get_instance(self._cw).add_data(
                     (workorder.eid, True) )
@@ -31,8 +31,3 @@ class UpdateProgressOnDoneForChange(hook.Hook):
     def __call__(self):
         UpdateProgressOp.get_instance(self._cw).add_data(
             (self.eidto, True))
-
-def registration_callback(vreg):
-    vreg.register_all(globals().values(), __name__)
-    from cubes.workorder.hooks import UpdateProgressOnWorkOrderStatusChange
-    vreg.unregister(UpdateProgressOnWorkOrderStatusChange)
