@@ -2,7 +2,7 @@
 """activity related views.
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -15,7 +15,7 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb.utils import UStringIO
 from cubicweb.schema import display_name
-from cubicweb.selectors import (is_instance, empty_rset, multi_columns_rset,
+from cubicweb.predicates import (is_instance, empty_rset, multi_columns_rset,
                                 match_user_groups, score_entity)
 from cubicweb.view import AnyRsetView, EntityView, EntityAdapter
 from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs, action
@@ -135,7 +135,7 @@ class ActivityCalendarItemView(calendar.CalendarItemView):
 
 
 class ValidateActivitiesAction(action.Action):
-    __regid__ = 'movetonext'
+    __regid__ = 'validate-activities'
     __select__ = (action.Action.__select__
                   & match_user_groups('managers')
                   & is_instance('Activity')
@@ -156,6 +156,29 @@ class ValidateActivitiesAction(action.Action):
         msg = self._cw._('activities validated')
         return self._cw.user_callback(validate_cb, (eids,), msg)
 
+class MoveActivitiesAction(action.Action):
+    __regid__ = 'move-activities'
+    __select__ = (action.Action.__select__
+                  & match_user_groups('managers')
+                  & is_instance('Activity')
+                  & score_entity(lambda x: x.cw_adapt_to('IWorkflowable').state == 'pending'))
+
+    category = 'mainactions'
+    submenu = _('move activities')
+
+    def actual_actions(self):
+        for item in self._cw.execute('Any W WHERE W is WorkOrder, W in_state S, S name "open"').entities():
+            yield self.build_action(item.dc_long_title(), self.url(item))
+
+    def url(self, workorder):
+        if self.cw_row is None:
+            eids = [str(row[self.cw_col or 0]) for row in self.cw_rset]
+        else:
+            eids = [str(self.cw_rset[self.cw_row][self.cw_col or 0])]
+        rql = 'SET X done_for Y WHERE X eid IN(%s), Y eid %%(y)s' % ','.join(eids)
+        msg = self._cw._('activities moved to workorder %s') % workorder.dc_long_title()
+        return self._cw.user_rql_callback((rql, {'y': workorder.eid}), msg)
+
 
 
 class ActivityIPrevNextAdapter(navigation.IPrevNextAdapter):
