@@ -1,7 +1,7 @@
 """gingouz specific boxes
 
 :organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,13 +9,13 @@ __docformat__ = "restructuredtext en"
 from datetime import date
 
 from logilab.common.date import first_day
+from logilab.common.registry import objectify_predicate
 from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
-from cubicweb.selectors import objectify_selector
 from cubicweb.web import component
 
-@objectify_selector
+@objectify_predicate
 def has_resource(cls, req, **kwargs):
     return bool(req.user.cw_adapt_to('timesheet.IResource'))
 
@@ -32,8 +32,9 @@ class ActivitiesBox(component.CtxComponent):
         title = self._cw._(self.title)
         url = self._cw.build_url(rql="Any C WHERE R use_calendar CU, CU use_calendar C, "
                                  "R euser U, U eid %s" % self._cw.user.eid)
-        title += u'&nbsp;&nbsp;<a href="%s" title="%s"><img alt="calendar icon" src="data/office-calendar.png"/> </a>' % (
-            xml_escape(url), self._cw._('see my calendars'))
+        title += u'&nbsp;&nbsp;<a href="%s" title="%s"><img alt="calendar icon" src="%s"/> </a>' % (
+            xml_escape(url), self._cw._('see my calendars'),
+            xml_escape(self._cw.data_url('office-calendar.png')))
         w(title)
 
     def render_body(self, w):
