@@ -1,14 +1,14 @@
 """activity related startup views.
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
 from logilab.common.date import strptime
 
-from cubicweb.selectors import match_form_params
+from cubicweb.predicates import match_form_params
 from cubicweb.view import StartupView
 from cubicweb.web import httpcache
 from cubicweb.web.views import startup
@@ -84,7 +84,7 @@ class MyActivities(startup.IndexView):
     def call(self):
         req = self._cw
         _ = req._
-        req.add_js( ('cubicweb.ajax.js', 'cubicweb.edition.js', 'cubes.gingouz.js') )
+        req.add_js( ('cubicweb.ajax.js', 'cubicweb.edition.js') )
         req.add_css('cubicweb.form.css')
         iresource = self._cw.user.cw_adapt_to('timesheet.IResource')
         if iresource:
